#[non_exhaustive]pub enum ArOperation<'a> {
Sum,
Min,
Max,
And,
Or,
Xor,
Match(&'a str),
Used,
}Expand description
Aggregate operation of the arop command
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sum
Sum of the numeric values.
Min
Smallest numeric value.
Max
Largest numeric value.
And
Bitwise AND, each value truncated towards zero to an integer.
Or
Bitwise OR, each value truncated towards zero to an integer.
Xor
Bitwise XOR, each value truncated towards zero to an integer.
Match(&'a str)
Number of elements equal to the given value.
Used
Number of non-empty elements.