pub enum BfInfoParameter {
Capacity,
Size,
NumFilters,
NumItemsInserted,
ExpansionRate,
}
Available on crate feature redis-bloom only.
Optional parameter for the bf_info command.
Used to query a specific parameter.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.