#[non_exhaustive]pub enum ClusterSlotStatsFilter {
SlotsRange {
start: u16,
end: u16,
},
OrderBy {
metric: ClusterSlotStatMetric,
limit: Option<usize>,
order: Option<SortOrder>,
},
}Expand description
Slot selection for the cluster_slot_stats command.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SlotsRange
Limit the results to an inclusive range of slots, sorted by slot number.
OrderBy
Sort the statistics by metric, optionally limiting the number of results
and choosing the sort order.