ClusterState

Enum ClusterState 

pub enum ClusterState {
    Ok,
    Fail,
}
Cluster state used in the cluster_state field of ClusterInfo

Variants



Ok

State is ok if the node is able to receive queries.



Fail

fail if there is at least one hash slot which is unbound (no node associated), in error state (node serving it is flagged with FAIL flag), or if the majority of masters can’t be reached by this node.