Enum rustis::commands::FunctionRestorePolicy
source · pub enum FunctionRestorePolicy {
Default,
Append,
Flush,
Replace,
}Expand description
Policy option for the function_restore command.
Variants
Default
Append
Append
Appends the restored libraries to the existing libraries and aborts on collision. This is the default policy.
Flush
Deletes all existing libraries before restoring the payload.
Replace
appends the restored libraries to the existing libraries, replacing any existing ones in case of name collisions. Note that this policy doesn’t prevent function name collisions, only libraries.