#[non_exhaustive]pub enum GetExOptions {
Ex(u64),
Px(u64),
Exat(u64),
Pxat(u64),
Persist,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ex(u64)
Set the specified expire time, in seconds.
Px(u64)
Set the specified expire time, in milliseconds.
Exat(u64)
Set the specified Unix time at which the key will expire, in seconds.
Pxat(u64)
Set the specified Unix time at which the key will expire, in milliseconds.
Persist
Remove the time to live associated with the key.