#[non_exhaustive]pub enum StreamEntryDeletionPolicy {
KeepRef,
DelRef,
Acked,
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
KeepRef
Remove the entry but keep consumer-group references (default, preserves pre-8.2 behaviour).
DelRef
Remove the entry and all references to it from every consumer group’s PEL.
Acked
Only remove entries already acknowledged by all consumer groups.