#[non_exhaustive]pub enum TsBucketTimestamp {
Low,
High,
Mid,
}Expand description
Which point of an aggregation bucket its reported timestamp is, for the
BUCKETTIMESTAMP option of the range commands.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Low
The bucket’s start time (the default when the option is absent).
High
The bucket’s end time.
Mid
The bucket’s mid time, rounded down when it is not an integer.