#[non_exhaustive]pub enum ZAddComparison {
GT,
LT,
}Expand description
Comparison option for the zadd command
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GT
Only update existing elements if the new score is greater than the current score.
This flag doesn’t prevent adding new elements.
LT
Only update existing elements if the new score is less than the current score.
This flag doesn’t prevent adding new elements.