ClientTrackingOptions

Struct ClientTrackingOptions 

pub struct ClientTrackingOptions { /* private fields */ }
Options for the client_tracking command.

Implementations

Source

impl ClientTrackingOptions

pub fn redirect(self, client_id: i64) -> Self

send invalidation messages to the connection with the specified ID.

pub fn broadcasting(self) -> Self

enable tracking in broadcasting mode.

pub fn prefix(self, prefix: impl Into<String>) -> Self

for broadcasting, register a given key prefix, so that notifications will be provided only for keys starting with this string.

This option can be given multiple times to register multiple prefixes.

pub fn optin(self) -> Self

when broadcasting is NOT active, normally don’t track keys in read only commands, unless they are called immediately after a CLIENT CACHING yes command.

pub fn optout(self) -> Self

when broadcasting is NOT active, normally track keys in read only commands, unless they are called immediately after a CLIENT CACHING no command.

pub fn noloop(self) -> Self

don’t send notifications about keys modified by this connection itself.