HotKeysInfo

Struct HotKeysInfo 

#[non_exhaustive]
pub struct HotKeysInfo { pub tracking_active: bool, pub sample_ratio: u32, pub selected_slots: Vec<(u16, u16)>, pub all_commands_all_slots_us: u64, pub net_bytes_all_commands_all_slots: u64, pub collection_start_time_unix_ms: u64, pub collection_duration_ms: u64, pub total_cpu_time_user_ms: Option<u64>, pub total_cpu_time_sys_ms: Option<u64>, pub total_net_bytes: Option<u64>, pub by_cpu_time_us: Option<Vec<(String, u64)>>, pub by_net_bytes: Option<Vec<(String, u64)>>, }
Result of one node for the hotkeys_get command.

The fields tied to a metric — the two total_cpu_time_*, total_net_bytes and the two rankings — are reported only for the metrics the session was started with, and are None otherwise.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
tracking_active: bool

whether tracking is still running

sample_ratio: u32

keys were tracked with probability 1/sample_ratio

selected_slots: Vec<(u16, u16)>

the inclusive slot ranges tracking was restricted to

all_commands_all_slots_us: u64

the CPU time, in microseconds, spent on every command of every tracked slot

net_bytes_all_commands_all_slots: u64

the network bytes used by every command of every tracked slot

collection_start_time_unix_ms: u64

when the session started, as a unix timestamp in milliseconds

collection_duration_ms: u64

for how long, in milliseconds, the session has been collecting

total_cpu_time_user_ms: Option<u64>

the user CPU time, in milliseconds, consumed during the session

total_cpu_time_sys_ms: Option<u64>

the system CPU time, in milliseconds, consumed during the session

total_net_bytes: Option<u64>

the network bytes used during the session

by_cpu_time_us: Option<Vec<(String, u64)>>

the hottest keys by CPU time, in microseconds, hottest first

by_net_bytes: Option<Vec<(String, u64)>>

the hottest keys by network bytes, hottest first