pub struct TsIncrByDecrByOptions { /* private fields */ }
Available on crate feature redis-time-series only.
Options for the ts_incrby and ts_decrby commands.

Notes

  • You can use this command to add data to a nonexisting time series in a single command. This is why retention, uncompressed, chunk_size, and labels are optional arguments.
  • When specified and the key doesn’t exist, a new time series is created. Setting the retention and labels options introduces additional time complexity.

Implementations

is (integer) UNIX sample timestamp in milliseconds or * to set the timestamp according to the server clock.

timestamp must be equal to or higher than the maximum existing timestamp. When equal, the value of the sample with the maximum existing timestamp is decreased. If it is higher, a new sample with a timestamp set to timestamp is created, and its value is set to the value of the sample with the maximum existing timestamp minus value.

If the time series is empty, the value is set to value.

When not specified, the timestamp is set according to the server clock.

maximum age for samples compared to the highest reported timestamp, in milliseconds.

Use it only if you are creating a new time series. It is ignored if you are adding samples to an existing time series

See retention.

changes data storage from compressed (default) to uncompressed.

Use it only if you are creating a new time series. It is ignored if you are adding samples to an existing time series. See encoding.

memory size, in bytes, allocated for each data chunk.

Use it only if you are creating a new time series. It is ignored if you are adding samples to an existing time series. See chunk_size.

set of label-value pairs that represent metadata labels of the time series.

Use it only if you are creating a new time series. It is ignored if you are adding samples to an existing time series. See labels.