XAutoClaimResult

Struct XAutoClaimResult 

#[non_exhaustive]
pub struct XAutoClaimResult<V>{ pub start_stream_id: String, pub entries: Vec<StreamEntry<V>>, pub deleted_ids: Vec<String>, }
Result for the xautoclaim command.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
start_stream_id: String

A stream ID to be used as the start argument for the next call to xautoclaim.

entries: Vec<StreamEntry<V>>

An array containing all the successfully claimed messages in the same format as xrange.

deleted_ids: Vec<String>

An array containing message IDs that no longer exist in the stream, and were deleted from the PEL in which they were found.