XClaimOptions

Struct XClaimOptions 

pub struct XClaimOptions { /* private fields */ }
Options for the xclaim command

Implementations

Source

impl XClaimOptions

pub fn idle_time(self, ms: u64) -> Self

Set the idle time (last time it was delivered) of the message.

pub fn time(self, unix_time_milliseconds: u64) -> Self

This is the same as idle_time but instead of a relative amount of milliseconds, it sets the idle time to a specific Unix time (in milliseconds).

pub fn retry_count(self, count: u32) -> Self

Set the retry counter to the specified value.

pub fn force(self) -> Self

Creates the pending message entry in the PEL even if certain specified IDs are not already in the PEL assigned to a different client.

pub fn just_id(self) -> Self

Return just an array of IDs of messages successfully claimed, without returning the actual message.

pub fn last_id(self, id: impl Into<String>) -> Self

Set the consumer group’s last delivered id to id.

Meant for a tool rebuilding a consumer group’s state; a normal claim has no reason to move the group’s cursor.