XGroupCreateOptions

Struct XGroupCreateOptions 

pub struct XGroupCreateOptions { /* private fields */ }
Options for the xgroup_create command

Implementations

Source

impl XGroupCreateOptions

pub fn mk_stream(self) -> Self

By default, the XGROUP CREATE command insists that the target stream exists and returns an error when it doesn’t. However, you can use the optional MKSTREAM subcommand as the last argument after the id to automatically create the stream (with length of 0) if it doesn’t exist

pub fn entries_read(self, entries_read: u32) -> Self

The optional entries_read named argument can be specified to enable consumer group lag tracking for an arbitrary ID. An arbitrary ID is any ID that isn’t the ID of the stream’s first entry, its last entry or the zero (“0-0”) ID. This can be useful you know exactly how many entries are between the arbitrary ID (excluding it) and the stream’s last entry. In such cases, the entries_read can be set to the stream’s entries_added subtracted with the number of entries.