#[non_exhaustive]pub enum ClusterBumpEpochResult {
Bumped(u64),
Still(u64),
}Expand description
Result for the cluster_bumpepoch command
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Bumped(u64)
The epoch was incremented, and the node now carries this one.
Still(u64)
The node already had the greatest config epoch in the cluster, this one.
Implementations