#[non_exhaustive]pub enum FtFieldType {
Text,
Tag,
Numeric,
Geo,
Geoshape(Option<FtGeoShapeCoordSystem>),
Vector(Option<FtVectorFieldAlgorithm>),
}Expand description
Field type used to declare an index schema
for the ft_create command
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Text
Allows full-text search queries against the value in this attribute.
Tag
Allows exact-match queries, such as categories or primary keys, against the value in this attribute.
For more information,
see Tag Fields.
Numeric
Allows numeric range queries against the value in this attribute.
See query syntax docs
for details on how to use numeric ranges.
Geo
Allows geographic range queries against the value in this attribute.
The value of the attribute must be a string containing a longitude (first) and latitude separated by a comma.
Geoshape(Option<FtGeoShapeCoordSystem>)
Allows polygon queries against the value in this attribute.
The value of the attribute must be a
WKT notation
list of 2D points representing the polygon edges, such as
POLYGON((x1 y1, x2 y2, ...)).
The coordinate system is optional and defaults to
Spherical.
Vector(Option<FtVectorFieldAlgorithm>)
Allows vector similarity queries against the value in this attribute.
For more information, see Vector Fields.