pub struct FtGroupBy<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FtGroupBy<'a>
impl<'a> FtGroupBy<'a>
Sourcepub fn reduce(self, reducer: FtReducer<'a>) -> Self
pub fn reduce(self, reducer: FtReducer<'a>) -> Self
reduces the matching results in each group into a single record, using a reduction function. For example, COUNT counts the number of records in the group. The reducers can have their own property names using the AS {name} optional argument. If a name is not given, the resulting name will be the name of the reduce function and the group properties. For example, if a name is not given to COUNT_DISTINCT by property @foo, the resulting name will be count_distinct(@foo).
See Supported GROUPBY reducers for more details.