pub struct XClaimOptions { /* private fields */ }Expand description
Options for the xclaim command
Implementations
Sourceimpl XClaimOptions
impl XClaimOptions
Sourcepub fn idle_time(self, ms: u64) -> Self
pub fn idle_time(self, ms: u64) -> Self
Set the idle time (last time it was delivered) of the message.
Sourcepub fn time(self, unix_time_milliseconds: u64) -> Self
pub fn time(self, unix_time_milliseconds: u64) -> Self
This is the same as idle_time but instead of a relative amount of milliseconds,
it sets the idle time to a specific Unix time (in milliseconds).
Sourcepub fn retry_count(self, count: u32) -> Self
pub fn retry_count(self, count: u32) -> Self
Set the retry counter to the specified value.
Sourcepub fn force(self) -> Self
pub fn force(self) -> Self
Creates the pending message entry in the PEL even if certain specified IDs are not already in the PEL assigned to a different client.